postgres.PostgresResultSetStore

|  | ## Cheshire3 Object Model: Class PostgresResultSetStore

Module postgres :: Class PostgresResultSetStore

## Class PostgresResultSetStore
source code

Object Tree:

                     object --+
                              |
          configParser.C3Object --+
                                  |
              baseStore.SimpleStore --+
                                      |
                          PostgresStore --+
                                          |
                 object --+               |
                          |               |
      configParser.C3Object --+           |
                              |           |
                    ObjectStore --+       |
                                  |       |
         baseObjects.ResultSetStore --+   |
                                      |   |
    resultSetStore.SimpleResultSetStore --+
                                          |
                                         PostgresResultSetStore

Instance Methods

__init__(self, session, node, parent)
_verifyDatabases(self, session)
store_data(self, session, id, data, size=0)
create_resultSet(self, session, rset)
store_resultSet(self, session, rset)
fetch_resultSet(self, session, rsid)
delete_resultSet(self, session, rsid)
fetch_resultSetList(self, session)
clean(self, session)
Inherited from `PostgresStore`: `begin_storing`, `commit_storing`, `delete_item`, `fetch_checksum`, `fetch_data`, `fetch_idList`, `fetch_size`, `generate_id`, `get_links`, `link`, `query`, `store_checkSum`, `unlink`, `verify_checkSum` Inherited from `PostgresStore` (private): `_closeContainer`, `_handleConfigNode`, `_openContainer` Inherited from `resultSetStore.SimpleResultSetStore` (private): `_verifyDefault` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `PostgresStore`: `cxn`, `relations` Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `resultSetStore.SimpleResultSetStore`: `databaseHash`, `databaseHashReverse`, `storeHash`, `storeHashReverse` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
Overrides: PostgresStore.__init__

### _verifyDatabases(self, session) | source code
Overrides: PostgresStore._verifyDatabases

### store_data(self, session, id, data, size=0) | source code
Overrides: PostgresStore.store_data

### create_resultSet(self, session, rset) | source code
Overrides: baseObjects.ResultSetStore.create_resultSet

### store_resultSet(self, session, rset) | source code
Overrides: baseObjects.ResultSetStore.store_resultSet

### fetch_resultSet(self, session, rsid) | source code
Overrides: baseObjects.ResultSetStore.fetch_resultSet

### delete_resultSet(self, session, rsid) | source code
Overrides: baseObjects.ResultSetStore.delete_resultSet

### fetch_resultSetList(self, session) | source code
Overrides: baseObjects.ResultSetStore.fetch_resultSetList

### clean(self, session) | source code